==> estateplat-common-1.2.4-20190114.103906-88-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtZlbxzr.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-06-13
 * @description 质量及保修责任历史表(第七章)
 */
@Table(name = "fcjy_xjspf_ba_mmht_zlbxzr")
public class FcjyXjspfBaMmhtZlbxzr extends FcjyXjspfBaParent {
    private String zrid;//主键
    private String htid;//合同ID
    private Double jcjgjflx;//基础结构给付利息(百分比)
    private String jcjgpcj;//基础结构赔偿金
    private String jcjgbjchtcl;//基础结构不解除合同处理
    private String qtzlcdpczr;//其他质量承担赔偿责任
    private Double qtzljflx;//其他质量给付利息(百分比)
    private String qtzlbjchtcl;//其他质量不解除合同处理
    private String zxbzclfs;//装修标准处理方式
    private String clfs3;//处理方式3
    private String clfs4;//处理方式4
    private String kqzlbzmc;//空气质量标准名称
    private String kqzlbzwh;//空气质量标准文号
    private String jzgsbzmc;//建筑隔声标准名称
    private String jzgsbzwh;//建筑隔声标准文号
    private Double zlgsjflx;//质量隔声给付利息(百分比)
    private String zlgsyqzr;//质量隔声逾期责任
    private String zlgspczr;//质量隔声赔偿责任
    private String bcdbxqx3;//不承担保修情形3
    private Integer bxsdqx;//保修送达期限(日)
    private String zldbldzr;//质量担保连带责任
    private String kqzlbzlx;//空气质量标准类型
    private String jzgsbzlx;//建筑隔声标准类型

    public String getZrid() {
        return zrid;
    }

    public void setZrid(String zrid) {
        this.zrid = zrid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public Double getJcjgjflx() {
        return jcjgjflx;
    }

    public void setJcjgjflx(Double jcjgjflx) {
        this.jcjgjflx = jcjgjflx;
    }

    public String getJcjgpcj() {
        return jcjgpcj;
    }

    public void setJcjgpcj(String jcjgpcj) {
        this.jcjgpcj = jcjgpcj;
    }

    public String getJcjgbjchtcl() {
        return jcjgbjchtcl;
    }

    public void setJcjgbjchtcl(String jcjgbjchtcl) {
        this.jcjgbjchtcl = jcjgbjchtcl;
    }

    public String getQtzlcdpczr() {
        return qtzlcdpczr;
    }

    public void setQtzlcdpczr(String qtzlcdpczr) {
        this.qtzlcdpczr = qtzlcdpczr;
    }

    public Double getQtzljflx() {
        return qtzljflx;
    }

    public void setQtzljflx(Double qtzljflx) {
        this.qtzljflx = qtzljflx;
    }

    public String getQtzlbjchtcl() {
        return qtzlbjchtcl;
    }

    public void setQtzlbjchtcl(String qtzlbjchtcl) {
        this.qtzlbjchtcl = qtzlbjchtcl;
    }

    public String getZxbzclfs() {
        return zxbzclfs;
    }

    public void setZxbzclfs(String zxbzclfs) {
        this.zxbzclfs = zxbzclfs;
    }

    public String getClfs3() {
        return clfs3;
    }

    public void setClfs3(String clfs3) {
        this.clfs3 = clfs3;
    }

    public String getClfs4() {
        return clfs4;
    }

    public void setClfs4(String clfs4) {
        this.clfs4 = clfs4;
    }

    public String getKqzlbzmc() {
        return kqzlbzmc;
    }

    public void setKqzlbzmc(String kqzlbzmc) {
        this.kqzlbzmc = kqzlbzmc;
    }

    public String getKqzlbzwh() {
        return kqzlbzwh;
    }

    public void setKqzlbzwh(String kqzlbzwh) {
        this.kqzlbzwh = kqzlbzwh;
    }

    public String getJzgsbzmc() {
        return jzgsbzmc;
    }

    public void setJzgsbzmc(String jzgsbzmc) {
        this.jzgsbzmc = jzgsbzmc;
    }

    public String getJzgsbzwh() {
        return jzgsbzwh;
    }

    public void setJzgsbzwh(String jzgsbzwh) {
        this.jzgsbzwh = jzgsbzwh;
    }

    public Double getZlgsjflx() {
        return zlgsjflx;
    }

    public void setZlgsjflx(Double zlgsjflx) {
        this.zlgsjflx = zlgsjflx;
    }

    public String getZlgsyqzr() {
        return zlgsyqzr;
    }

    public void setZlgsyqzr(String zlgsyqzr) {
        this.zlgsyqzr = zlgsyqzr;
    }

    public String getZlgspczr() {
        return zlgspczr;
    }

    public void setZlgspczr(String zlgspczr) {
        this.zlgspczr = zlgspczr;
    }

    public String getBcdbxqx3() {
        return bcdbxqx3;
    }

    public void setBcdbxqx3(String bcdbxqx3) {
        this.bcdbxqx3 = bcdbxqx3;
    }

    public Integer getBxsdqx() {
        return bxsdqx;
    }

    public void setBxsdqx(Integer bxsdqx) {
        this.bxsdqx = bxsdqx;
    }

    public String getZldbldzr() {
        return zldbldzr;
    }

    public void setZldbldzr(String zldbldzr) {
        this.zldbldzr = zldbldzr;
    }

    public String getKqzlbzlx() {
        return kqzlbzlx;
    }

    public void setKqzlbzlx(String kqzlbzlx) {
        this.kqzlbzlx = kqzlbzlx;
    }

    public String getJzgsbzlx() {
        return jzgsbzlx;
    }

    public void setJzgsbzlx(String jzgsbzlx) {
        this.jzgsbzlx = jzgsbzlx;
    }
}

==> estateplat-common-1.2.4-20210721.074940-823-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtZlbxzr.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-06-13
 * @description 质量及保修责任历史表(第七章)
 */
@Table(name = "fcjy_xjspf_ba_mmht_zlbxzr")
public class FcjyXjspfBaMmhtZlbxzr extends FcjyXjspfBaParent {
    private String zrid;//主键
    private String htid;//合同ID
    private String jcjgjflx;//基础结构给付利息(百分比)
    private String jcjgpcj;//基础结构赔偿金
    private String jcjgbjchtcl;//基础结构不解除合同处理
    private String qtzlcdpczr;//其他质量承担赔偿责任
    private String qtzljflx;//其他质量给付利息(百分比)
    private String qtzlbjchtcl;//其他质量不解除合同处理
    private String zxbzclfs;//装修标准处理方式
    private String clfs3;//处理方式3
    private String clfs4;//处理方式4
    private String kqzlbzmc;//空气质量标准名称
    private String kqzlbzwh;//空气质量标准文号
    private String jzgsbzmc;//建筑隔声标准名称
    private String jzgsbzwh;//建筑隔声标准文号
    private String zlgsjflx;//质量隔声给付利息(百分比)
    private String zlgsyqzr;//质量隔声逾期责任
    private String zlgspczr;//质量隔声赔偿责任
    private String bcdbxqx3;//不承担保修情形3
    private Integer bxsdqx;//保修送达期限(日)
    private String zldbldzr;//质量担保连带责任
    private String kqzlbzlx;//空气质量标准类型
    private String jzgsbzlx;//建筑隔声标准类型

    public String getZrid() {
        return zrid;
    }

    public void setZrid(String zrid) {
        this.zrid = zrid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getJcjgjflx() {
        return jcjgjflx;
    }

    public void setJcjgjflx(String jcjgjflx) {
        this.jcjgjflx = jcjgjflx;
    }

    public String getJcjgpcj() {
        return jcjgpcj;
    }

    public void setJcjgpcj(String jcjgpcj) {
        this.jcjgpcj = jcjgpcj;
    }

    public String getJcjgbjchtcl() {
        return jcjgbjchtcl;
    }

    public void setJcjgbjchtcl(String jcjgbjchtcl) {
        this.jcjgbjchtcl = jcjgbjchtcl;
    }

    public String getQtzlcdpczr() {
        return qtzlcdpczr;
    }

    public void setQtzlcdpczr(String qtzlcdpczr) {
        this.qtzlcdpczr = qtzlcdpczr;
    }

    public String getQtzljflx() {
        return qtzljflx;
    }

    public void setQtzljflx(String qtzljflx) {
        this.qtzljflx = qtzljflx;
    }

    public String getQtzlbjchtcl() {
        return qtzlbjchtcl;
    }

    public void setQtzlbjchtcl(String qtzlbjchtcl) {
        this.qtzlbjchtcl = qtzlbjchtcl;
    }

    public String getZxbzclfs() {
        return zxbzclfs;
    }

    public void setZxbzclfs(String zxbzclfs) {
        this.zxbzclfs = zxbzclfs;
    }

    public String getClfs3() {
        return clfs3;
    }

    public void setClfs3(String clfs3) {
        this.clfs3 = clfs3;
    }

    public String getClfs4() {
        return clfs4;
    }

    public void setClfs4(String clfs4) {
        this.clfs4 = clfs4;
    }

    public String getKqzlbzmc() {
        return kqzlbzmc;
    }

    public void setKqzlbzmc(String kqzlbzmc) {
        this.kqzlbzmc = kqzlbzmc;
    }

    public String getKqzlbzwh() {
        return kqzlbzwh;
    }

    public void setKqzlbzwh(String kqzlbzwh) {
        this.kqzlbzwh = kqzlbzwh;
    }

    public String getJzgsbzmc() {
        return jzgsbzmc;
    }

    public void setJzgsbzmc(String jzgsbzmc) {
        this.jzgsbzmc = jzgsbzmc;
    }

    public String getJzgsbzwh() {
        return jzgsbzwh;
    }

    public void setJzgsbzwh(String jzgsbzwh) {
        this.jzgsbzwh = jzgsbzwh;
    }

    public String getZlgsjflx() {
        return zlgsjflx;
    }

    public void setZlgsjflx(String zlgsjflx) {
        this.zlgsjflx = zlgsjflx;
    }

    public String getZlgsyqzr() {
        return zlgsyqzr;
    }

    public void setZlgsyqzr(String zlgsyqzr) {
        this.zlgsyqzr = zlgsyqzr;
    }

    public String getZlgspczr() {
        return zlgspczr;
    }

    public void setZlgspczr(String zlgspczr) {
        this.zlgspczr = zlgspczr;
    }

    public String getBcdbxqx3() {
        return bcdbxqx3;
    }

    public void setBcdbxqx3(String bcdbxqx3) {
        this.bcdbxqx3 = bcdbxqx3;
    }

    public Integer getBxsdqx() {
        return bxsdqx;
    }

    public void setBxsdqx(Integer bxsdqx) {
        this.bxsdqx = bxsdqx;
    }

    public String getZldbldzr() {
        return zldbldzr;
    }

    public void setZldbldzr(String zldbldzr) {
        this.zldbldzr = zldbldzr;
    }

    public String getKqzlbzlx() {
        return kqzlbzlx;
    }

    public void setKqzlbzlx(String kqzlbzlx) {
        this.kqzlbzlx = kqzlbzlx;
    }

    public String getJzgsbzlx() {
        return jzgsbzlx;
    }

    public void setJzgsbzlx(String jzgsbzlx) {
        this.jzgsbzlx = jzgsbzlx;
    }
}
